/* Define to the unsigned int type. */
#undef uint

/* Define to activate module loader. */
#undef USE_MODULES

/* Define for automatic version check. */
#undef CHECK_VERSION

/* Define to activate debugging mode. */
#undef DEBUG

/* Define if you have the bz2 library (-lbz2).  */
#undef HAVE_LIBBZ2

/* Define if you have the z library (-lz).  */
#undef HAVE_LIBZ

/* Define if you have the compress2 function.  */
#undef HAVE_COMPRESS2

/* Define if you have a newer libbz2 implementation function.  */
#undef HAVE_NEW_BZ2

/* Define if you have the inet_aton function.  */
#undef HAVE_INET_ATON

/* Define if you want to disable network support */
#undef NO_NETWORK

/* Define if you have gzdopen() in -lz, for native support of .gz files */
#undef HAVE_GZDOPEN

/* Define if you have bzdopen() in -lbz2, for native support of .bz2 files */
#undef HAVE_BZDOPEN

/* Define if you have a new bzip2 implementation that uses BZ2_name */
#undef HAVE_NEW_BZDOPEN

/* Define if you have /dev/urandom */
#undef HAVE_DEV_URANDOM

/* Define if you have the libmcrypt library installed */
#undef HAVE_LIBMCRYPT

/* Define to the unsigned 32 bit type. */
#undef uint32_t

/* Define to the signed 32 bit type. */
#undef int32_t

/* Define to the unsigned 16 bit type. */
#undef uint16_t

/* Define to the signed 16 bit type*/
#undef int16_t
